@@ -22,6 +22,7 @@
 
 #include "seahorse-gkr-dialogs.h"
 #include "seahorse-gkr-keyring.h"
+#include "seahorse-gkr-source.h"
 
 #include "seahorse-widget.h"
 #include "seahorse-util.h"
@@ -106,6 +107,8 @@ static void
 keyring_add_done (GnomeKeyringResult result, gpointer data)
 {
 	SeahorseWidget *swidget = SEAHORSE_WIDGET (data);
+	SeahorseOperation *op;
+
 	g_return_if_fail (swidget);
 
 	/* Clear the operation without cancelling it since it is complete */
@@ -113,14 +116,25 @@ keyring_add_done (GnomeKeyringResult result, gpointer data)
     
 	/* Successful. Update the listings and stuff. */
 	if (result == GNOME_KEYRING_RESULT_OK) {
-		/* TODO: refresh_keyrings (swidget); */
-        
+		
+		op = seahorse_source_load (SEAHORSE_SOURCE (seahorse_gkr_source_default ()));
+		
+		/* 
+		 * HACK: Major hack alert. This whole area needs some serious refactoring,
+		 * so for now we're just going to let any viewers listen in on this
+		 * operation like so:
+		 */
+		g_signal_emit_by_name (seahorse_context_for_app (), "refreshing", op);
+		g_object_unref (op);
+
 	/* Setting the default keyring failed */
 	} else if (result != GNOME_KEYRING_RESULT_CANCELLED) {     
 		seahorse_util_show_error (seahorse_widget_get_toplevel (swidget),
 		                          _("Couldn't add keyring"),
 		                          gnome_keyring_result_to_message (result));
 	}
+	
+	seahorse_widget_destroy (swidget);
 }
 
 static void
@@ -139,10 +153,8 @@ properties_response (GtkDialog *dialog, int response, SeahorseWidget *swidget)
 	
 	if (response == GTK_RESPONSE_HELP) {
 		seahorse_widget_show_help (swidget);
-		return;
-	}
-
-	if (response == GTK_RESPONSE_ACCEPT) {
+		
+	} else if (response == GTK_RESPONSE_ACCEPT) {
 	    
 		entry = GTK_ENTRY (seahorse_widget_get_widget (swidget, "keyring-name"));
 		g_return_if_fail (entry); 
@@ -150,12 +162,13 @@ properties_response (GtkDialog *dialog, int response, SeahorseWidget *swidget)
 		keyring = gtk_entry_get_text (entry);
 		g_return_if_fail (keyring && keyring[0]);
 	    
-		request = gnome_keyring_create (keyring, NULL, keyring_add_done, swidget, NULL);
+		request = gnome_keyring_create (keyring, NULL, keyring_add_done, g_object_ref (swidget), g_object_unref);
 		g_return_if_fail (request);
 		setup_request (swidget, request);
+		
+	} else {
+		seahorse_widget_destroy (swidget);
 	}
-
-	seahorse_widget_destroy (swidget);
 }
 
 void
@@ -177,4 +190,7 @@ seahorse_gkr_add_keyring_show (GtkWindow *parent)
 
 	widget = seahorse_widget_get_toplevel (swidget);
 	g_signal_connect (widget, "response", G_CALLBACK (properties_response), swidget);
+	
+	gtk_widget_show (widget);
+	gtk_window_present (GTK_WINDOW (widget));
 }
