@@ -19,7 +19,10 @@
  * Boston, MA 02111-1307, USA.
  */
 #include <config.h>
-#include <gnome.h>
+
+#include <glib/gi18n.h>
+
+#include <string.h>
 
 #include "seahorse-validity.h"
 
@@ -30,7 +33,7 @@ seahorse_validity_get_string (SeahorseValidity validity)
 		case SEAHORSE_VALIDITY_UNKNOWN:
 			return _("Unknown");
 		case SEAHORSE_VALIDITY_NEVER:
-			return _("Never");
+			return C_("Validity", "Never");
 		case SEAHORSE_VALIDITY_MARGINAL:
 			return _("Marginal");
 		case SEAHORSE_VALIDITY_FULL:
@@ -46,22 +49,3 @@ seahorse_validity_get_string (SeahorseValidity validity)
 	}
 }
 
-SeahorseValidity    
-seahorse_validity_from_gpgme (gpgme_validity_t validity)
-{
-    switch (validity) {
-    case GPGME_VALIDITY_NEVER:
-        return SEAHORSE_VALIDITY_NEVER;
-    case GPGME_VALIDITY_MARGINAL:
-        return SEAHORSE_VALIDITY_MARGINAL;
-    case GPGME_VALIDITY_FULL:
-        return SEAHORSE_VALIDITY_FULL;
-    case GPGME_VALIDITY_ULTIMATE:
-        return SEAHORSE_VALIDITY_ULTIMATE;
-    case GPGME_VALIDITY_UNDEFINED:
-    case GPGME_VALIDITY_UNKNOWN:
-    default:
-        return SEAHORSE_VALIDITY_UNKNOWN;
-    }
-}
-
